using System;

namespace IMusicCommon{

    public class MusicCommon{

        static private string[] NoteNamesRu = new string[12] { "Do", "Do#", "Re", "Re#", "Mi", "Fa", "Fa#", "Sol", "Sol#", "La", "La#", "Si" };
        static private string[] NoteNamesEn = new string[12] { "C", "C#", "D", "D#", "E", "F", "F#", "G", "G#", "A", "A#", "B" };
        static private string[] Modifiers = new string[12] { "", "#", "", "#", "", "", "#", "", "#", "", "#", "" };
        // midi note 59 - zerro position, middle line on notelines
        static float midinoteZerro = 59f;

         static public string MidiNoteToName(int midinote, string lang = "RU"){
            if (lang == "EN") {
                return NoteNamesEn[midinote % 12]; }
            else
            {
                return NoteNamesRu[midinote % 12];
            };
          } // end of MidiToNoteName

        static public string MidiNoteModifier(int midinote, string lang = "EN")
        {
                return Modifiers[midinote % 12]; 
        }


         static public float MidiNoteToLinePosition(int midinote){
             float pos = 0;

             if (MusicCommon.MidiNoteModifier(midinote) == "#") {
                 midinote--;
             };

             // remove all modifiers
             for (float i = midinoteZerro; i < midinote; i++)
             {
                 if (MusicCommon.MidiNoteModifier((int)i) != "#")
                 {
                     pos = pos - 0.5f;
                 };
             };

             for (float i = midinote; i < midinoteZerro; i++)
             {
                 if (MusicCommon.MidiNoteModifier((int)i) != "#")
                 {
                     pos = pos + 0.5f;
                 };
             };


             return pos;
         } // end of MidiNoteToLinePosition

         static public int LinePositionToMidiNote(float linepos)
         {
             int midinote = (int)midinoteZerro;
             // move down
             for (float i = 0; i < linepos; i = i + 0.5f ) {
                 midinote = midinote - 1; // sound tone up down
                 if (MusicCommon.MidiNoteModifier(midinote) == "#") {
                     midinote = midinote - 1;
                 };
             };

             // move up (negative line position)
             for (float i = 0; i > linepos; i = i - 0.5f)
             {
                 midinote = midinote + 1; // sound tone up
                 if (MusicCommon.MidiNoteModifier(midinote) == "#")
                 {
                     midinote = midinote + 1;
                 };
             };

             return midinote;
         } // end of LinePositionToMidiNote

 }
}
